@@ -1,9 +1,9 @@
-from .geoms import geom_point_3d, geom_polygon_3d, geom_line_3d, geom_voxel_3d, geom_text_3d
+from .geoms import geom_point_3d, geom_polygon_3d, geom_line_3d, geom_voxel_3d, geom_text_3d, geom_label_3d
 from .plot import ggplot_3d
 from .labels import zlab
 
 
-__version__ = '0.0.4'
+__version__ = '0.0.6'
 
 
 __all__ = [
@@ -11,6 +11,7 @@ __all__ = [
     'geom_polygon_3d',
     'geom_point_3d',
     'geom_voxel_3d',
+    'geom_label_3d',
     'geom_text_3d',
     'zlab',
     'ggplot_3d'
